const mix = require('laravel-mix'),
    glob = require('glob'),
    autoprefixer = require('autoprefixer'),
    dotenv = require('dotenv').config()

if (dotenv.error) {
    throw dotenv.error
}

const env = dotenv.parsed,
    bsProxy = env.BROWSERSYNC_PROXY || 'primera',
    sourcePath = 'source/',
    publicPath = 'public/',
    jsFiles = glob.sync(`${sourcePath}/js/*.js`),
    // sassFiles = glob.sync(`${sourcePath}/scss/*.scss`),
    postCssFiles = glob.sync(`${sourcePath}/css/*.css`)

// https://laravel-mix.com/docs/5.0/faq#my-mix-manifestjson-file-shouldnt-be-in-the-project-root
mix.setPublicPath(publicPath)

mix.disableNotifications()

// https://laravel-mix.com/docs/5.0/options
mix.options({
    processCssUrls: false,
    postCss: [
        autoprefixer,
    ],
});

// https://browsersync.io/docs/options/
mix.browserSync({
    // watchEvents: ['change', 'add', 'unlink', 'addDir', 'unlinkDir'],
    proxy: bsProxy,
    tunnel: false, // string|bool
    notify: false,
    open: false,
    files: [
        "./app/**/*.php",
        "./source/views/**/**/*.php",
        "./public/img/**/*",
    ],
});

jsFiles.forEach(filename => mix.js(filename, publicPath + 'js'))
// sassFiles.forEach(filename => mix.sass(filename, publicPath + 'css'))
postCssFiles.forEach(filename => mix.postCss(filename, publicPath + 'css'))

if (! mix.inProduction()) {
    mix.sourceMaps()
}
mix.version()

// Full API:
// mix.js(src, output);
// mix.react(src, output); <-- Identical to mix.js(), but registers React Babel compilation.
// mix.preact(src, output); <-- Identical to mix.js(), but registers Preact compilation.
// mix.coffee(src, output); <-- Identical to mix.js(), but registers CoffeeScript compilation.
// mix.ts(src, output); <-- TypeScript support. Requires tsconfig.json to exist in the same folder as webpack.mix.js
// mix.extract(vendorLibs);
// mix.sass(src, output);
// mix.less(src, output);
// mix.stylus(src, output);
// mix.postCss(src, output, [require('postcss-some-plugin')()]);
// mix.browserSync('my-site.test');
// mix.combine(files, destination);
// mix.babel(files, destination); <-- Identical to mix.combine(), but also includes Babel compilation.
// mix.copy(from, to);
// mix.copyDirectory(fromDir, toDir);
// mix.minify(file);
// mix.sourceMaps(); // Enable sourcemaps
// mix.version(); // Enable versioning.
// mix.disableNotifications();
// mix.setPublicPath('path/to/public');
// mix.setResourceRoot('prefix/for/resource/locators');
// mix.autoload({}); <-- Will be passed to Webpack's ProvidePlugin.
// mix.webpackConfig({}); <-- Override webpack.config.js, without editing the file directly.
// mix.babelConfig({}); <-- Merge extra Babel configuration (plugins, etc.) with Mix's default.
// mix.then(function () {}) <-- Will be triggered each time Webpack finishes building.
// mix.override(function (webpackConfig) {}) <-- Will be triggered once the webpack config object has been fully generated by Mix.
// mix.dump(); <-- Dump the generated webpack config object to the console.
// mix.extend(name, handler) <-- Extend Mix's API with your own components.
// mix.options({
//   extractVueStyles: false, // Extract .vue component styling to file, rather than inline.
//   globalVueStyles: file, // Variables file to be imported in every component.
//   processCssUrls: true, // Process/optimize relative stylesheet url()'s. Set to false, if you don't want them touched.
//   purifyCss: false, // Remove unused CSS selectors.
//   terser: {}, // Terser-specific options. https://github.com/webpack-contrib/terser-webpack-plugin#options
//   postCss: [] // Post-CSS options: https://github.com/postcss/postcss/blob/master/docs/plugins.md
// });
